<?php

// Files Includes
include get_theme_file_path('/inc/class-tgm-plugin-activation.php');
include get_theme_file_path('/inc/class-wp-bootstrap-navwalker.php');
include get_theme_file_path('/inc/elementor/elementor.php');

// myfolio setup
if ( ! function_exists( 'myfolio_setup' ) ) :

	function myfolio_setup() {

		load_theme_textdomain( 'myfolio', get_template_directory() . '/languages' );

		add_editor_style();

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );

		add_theme_support( 'post-thumbnails' );

		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'myfolio' ),
			'footer' => esc_html__( 'Footer', 'myfolio' ),
		) );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'custom-background', apply_filters( 'myfolio_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		add_theme_support( 'customize-selective-refresh-widgets' );

		add_theme_support( 'wp-block-styles' );

		add_theme_support( 'align-wide' );

		add_theme_support( 'alignfull ' );

		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => __( 'Strong Blue', 'myfolio' ),
				'slug'  => 'strong-blue',
				'color' => '#0073aa',
			),
			array(
				'name'  => __( 'Lighter Blue', 'myfolio' ),
				'slug'  => 'lighter-blue',
				'color' => '#229fd8',
			),
			array(
				'name'  => __( 'Very Light Gray', 'myfolio' ),
				'slug'  => 'very-light-gray',
				'color' => '#eee',
			),
			array(
				'name'  => __( 'Very Dark Gray', 'myfolio' ),
				'slug'  => 'very-dark-gray',
				'color' => '#444',
			),
		) );

		add_theme_support( 'responsive-embeds' );

		add_theme_support('editor-styles');

		add_editor_style( 'style-editor.css' );

		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true
		) );

		add_image_size( 'myfolio-single-page-image', 1280,720, true );
		add_image_size( 'myfolio-600x770',600,770, true );
		add_image_size( 'myfolio-team-250x250', 250,250, true );
		add_image_size( 'myfolio-80x80', 80,80, true );
		add_image_size( 'myfolio-100x100', 100,100, true );
		add_image_size( 'myfolio-team-1280x600', 1280,600, true );

	}

endif;

add_action( 'after_setup_theme', 'myfolio_setup' );

// content width
function myfolio_content_width() {
	
	$GLOBALS['content_width'] = apply_filters( 'myfolio_content_width', 640 );
}
add_action( 'after_setup_theme', 'myfolio_content_width', 0 );

// Register widget area
function myfolio_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'myfolio' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'myfolio' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'myfolio_widgets_init' );

// Enqueue scripts and styles.
function myfolio_scripts() {
	wp_enqueue_style( 'bootstrap', get_stylesheet_directory_uri() . '/css/bootstrap.min.css');
	wp_enqueue_style( 'font-awesome', get_stylesheet_directory_uri() . '/css/font-awesome.min.css');
	wp_enqueue_style( 'slick', get_stylesheet_directory_uri() . '/css/slick.css');
	wp_enqueue_style( 'bxslider', get_stylesheet_directory_uri() . '/css/bx-slider.css');
	wp_enqueue_style( 'magnific-popup', get_stylesheet_directory_uri() . '/css/magnific-popup.css');
	wp_enqueue_style( 'myfolio-style', get_stylesheet_uri());


	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'counterup', get_theme_file_uri('/js/jquery.counterup.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'waypoints', get_theme_file_uri('/js/jquery.waypoints.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'popper', get_theme_file_uri('/js/popper.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'bxslider', get_theme_file_uri('/js/jquery.bxslider.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'magnific-popup', get_theme_file_uri('/js/jquery.magnific-popup.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'bootstrap', get_theme_file_uri('/js/bootstrap.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'slick', get_theme_file_uri('/js/slick.min.js') , array(), '20151215', true );
	wp_enqueue_script( 'myfolio-skip-link-focus-fix', get_theme_file_uri('/js/skip-link-focus-fix.js') , array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_script( 'main', get_theme_file_uri() . '/js/main.js', array(), '1.0.0', true );
}
add_action( 'wp_enqueue_scripts', 'myfolio_scripts' );

//Exclude pages from WordPress Search
if (!is_admin()) {
	function myfolio_search_filter($query) {
		if ($query->is_search) {
			$query->set('post_type', 'post');
		}
		return $query;
	}
	add_filter('pre_get_posts','myfolio_search_filter');
}

// One click demo import
function myfolio_import_files() {
  return array(
    array(
      'import_file_name'  => 'myfolio Demo Import',
      'local_import_file' => trailingslashit( get_template_directory() ) . 'demo/content.xml',
    )
  );
}
add_filter( 'pt-ocdi/import_files', 'myfolio_import_files' );

// Breadcrumb Start  
function myfolio_breadcrumb()
{
	$showOnHome = 1;
	$delimiter = '<i class="fa fa-angle-right"></i>';
	$home = esc_html__('Home', 'myfolio');
	$showCurrent = 1;
	$before = '<span class="active">';
	$after = '</span>';
	global $post;
	$homeLink = home_url();
	if (is_home() || is_front_page()) {
		if ($showOnHome == 1 && is_home()) echo '<ol class="breadcrumb"><li><a href="' . esc_url($homeLink) . '">' . esc_html($home) . '</a></li></ol>';
	}
	else {
		echo '<ol class="breadcrumb"><li><a href="' . esc_url($homeLink) . '">' . esc_html($home) . '</a> ' . $delimiter . '</li>';
		if (is_category()) {
			$thisCat = get_category(get_query_var('cat') , false);
			if ($thisCat->parent != 0) echo get_category_parents($thisCat->parent, TRUE, ' ' . $delimiter . ' ');
			echo $before . esc_html__('Archive by category "', 'myfolio') . single_cat_title('', false) . esc_html__('"', 'myfolio') . $after;
		}
		elseif (is_search()) {
			echo $before . esc_html__('Search results for "', 'myfolio') . get_search_query() . esc_html__('"', 'myfolio') . $after;
		}
		elseif (is_day()) {
			echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
			echo '<li><a href="' . get_month_link(get_the_time('Y') , get_the_time('m')) . '">' . get_the_time('F') . '</a></li> ' . $delimiter . ' ';
			echo $before . get_the_time('d') . $after;
		}
		elseif (is_month()) {
			echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
			echo $before . get_the_time('F') . $after;
		}
		elseif (is_year()) {
			echo $before . get_the_time('Y') . $after;
		}
		elseif (is_single() && !is_attachment()) {
			if (get_post_type() != 'post') {
				$post_type = get_post_type_object(get_post_type());
				$slug = $post_type->rewrite;
				echo '<li><a href="' . esc_url($homeLink) . '/' . esc_attr($slug['slug']) . '/">' . esc_html($post_type->labels->singular_name) . '</a></li>';
				if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
			}
			else {
				$cat = get_the_category();
				$cat = $cat[0];
				$cats = get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
				if ($showCurrent == 0) $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
				echo $cats;
				if ($showCurrent == 1) echo $before . get_the_title() . $after;
			}
		}
		elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
			$post_type = get_post_type_object(get_post_type());
			echo $before . esc_html($post_type->labels->singular_name) . $after;
		}
		elseif (is_attachment()) {
			$parent = get_post($post->post_parent);
			$cat = get_the_category($parent->ID);
			$cat = $cat[0];
			echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
			echo '<li><a href="' . get_permalink($parent) . '">' . esc_html($parent->post_title) . '</a></li>';
			if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
		}
		elseif (is_page() && !$post->post_parent) {
			if ($showCurrent == 1) echo $before . get_the_title() . $after;
		}
		elseif (is_page() && $post->post_parent) {
			$parent_id = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) {
				$page = get_page($parent_id);
				$breadcrumbs[] = '<li><a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a></li>';
				$parent_id = $page->post_parent;
			}

			$breadcrumbs = array_reverse($breadcrumbs);
			for ($i = 0; $i < count($breadcrumbs); $i++) {
				echo $breadcrumbs[$i];
				if ($i != count($breadcrumbs) - 1) echo ' ' . $delimiter . ' ';
			}

			if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
		}
		elseif (is_tag()) {
			echo $before . esc_html__('Posts tagged "', 'myfolio') . single_tag_title('', false) . esc_html__('"', 'myfolio') . $after;
		}
		elseif (is_author()) {
			global $author;
			$userdata = get_userdata($author);
			echo $before . esc_html__('Articles posted by "', 'myfolio') . esc_html($userdata->display_name) . esc_html__('"', 'myfolio') . $after;
		}
		elseif (is_404()) {
			echo $before . esc_html__('Error 404', 'myfolio') . $after;
		}

		if (get_query_var('paged')) {
			if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) echo esc_html__(' (', 'myfolio');
			echo esc_html__('Page', 'myfolio') . ' ' . get_query_var('paged');
			if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) echo esc_html__(')', 'myfolio');
		}

		echo '</ol>';
	}
}


// entry footer
function myfolio_entry_footer() {
	if ('post' === get_post_type()) {
		$categories_list = get_the_category_list(esc_html__(', ', 'myfolio'));
		if ($categories_list) {
			printf('<span class="cat-links">' . esc_html__('Posted in %1$s', 'myfolio') . '</span>', $categories_list);
		}

		$tags_list = get_the_tag_list('', esc_html_x(', ', 'list item separator', 'myfolio'));
		if ($tags_list) {
			printf('<span class="tags-links">' . esc_html__('Tagged %1$s', 'myfolio') . '</span>', $tags_list);
		}
	}

	if (!is_single() && !post_password_required() && (comments_open() || get_comments_number())) {
		echo '<span class="comments-link">';
		comments_popup_link(sprintf(wp_kses(__('Leave a Comment<span class="screen-reader-text"> on %s</span>', 'myfolio') , array(
			'span' => array(
				'class' => array() ,
			) ,
		)) , get_the_title()));
		echo '</span>';
	}

	edit_post_link(sprintf(wp_kses(__('Edit <span class="screen-reader-text">%s</span>', 'myfolio') , array(
		'span' => array(
			'class' => array() ,
		) ,
	)) , get_the_title()) , '<span class="edit-link">', '</span>');
}


// required plugins

function myfolio_register_required_plugins() {
	
	$plugins = array(
		
		array(
			'name'      => 'Kirki',
			'slug'      => 'kirki',
			'required'  => true,
		),
		array(
			'name'      => 'Elementor Page Builder',
			'slug'      => 'elementor',
			'required'  => true,
		),
		array(
			'name'        => 'Yeadh plugin',
			'slug'        => 'yeadh-plugin', 
			'source'      => 'https://github.com/yeadh/yeadh-plugin/archive/master.zip', 
			'required'    => true
		),
		array(
			'name'      => 'Contact Form 7',
			'slug'      => 'contact-form-7',
			'required'  => true,
		),
		array(
			'name'      => 'One Click Demo Import',
			'slug'      => 'one-click-demo-import',
			'required'  => true,
		),
	);

	
	$config = array(
		'id'           => 'tgmpa',                 
		'default_path' => '',                      
		'menu'         => 'tgmpa-install-plugins', 
		'parent_slug'  => 'themes.php',            
		'capability'   => 'edit_theme_options',
		'has_notices'  => true,                    
		'dismissable'  => true,                    
		'dismiss_msg'  => '',     
		'is_automatic' => false, 
		'message'      => '',
	);

	tgmpa( $plugins, $config );
}

add_action( 'tgmpa_register', 'myfolio_register_required_plugins' );


// myfolio pagination
if ( ! function_exists ( 'myfolio_pagination' ) ) {

	function myfolio_pagination( $args = array(), $class = 'pagination' ) {

        if ($GLOBALS['wp_query']->max_num_pages <= 1) return;

		$args = wp_parse_args( $args, array(
			'mid_size'           => 2,
			'prev_next'          => true,
			'prev_text'          => __('&laquo;', 'myfolio'),
			'next_text'          => __('&raquo;', 'myfolio'),
			'screen_reader_text' => __('Posts navigation', 'myfolio'),
			'type'               => 'array',
			'current'            => max( 1, get_query_var('paged') ),
		) );

        $links = paginate_links($args);

        ?>

        <nav aria-label="<?php echo $args['screen_reader_text']; ?>">

            <ul class="pagination">

                <?php

                    foreach ( $links as $key => $link ) { ?>

                        <li class="page-item <?php echo strpos( $link, 'current' ) ? 'active' : '' ?>">

                            <?php echo str_replace( 'page-numbers', 'page-link', $link ); ?>

                        </li>

                <?php } ?>

            </ul>

        </nav>

        <?php
    }
}


// myfolio Theme Customizer
function myfolio_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'myfolio_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'myfolio_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'myfolio_customize_register' );

// Render the site title for the selective refresh partial.
function myfolio_customize_partial_blogname() {
	bloginfo( 'name' );
}

// Render the site tagline for the selective refresh partial.
function myfolio_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

// Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
function myfolio_customize_preview_js() {
	wp_enqueue_script( 'myfolio-customizer', get_theme_file_uri('/js/customizer.js') , array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'myfolio_customize_preview_js' );

// Kirki Theme Option
if (class_exists('Kirki')) {

	Kirki::add_config('theme_config_id', array(
		'capability' => 'edit_theme_options',
		'option_type' => 'theme_mod',
	));
	Kirki::add_panel('myfolio_panel', array(
		'priority' => 10,
		'title' => esc_attr__('myfolio Theme Option', 'myfolio') ,
	));

	// header section

	Kirki::add_section('header_section', array(
		'title' => esc_attr__('Header', 'myfolio') ,
		'panel' => 'myfolio_panel',
		'priority' => 160,
	));

	// blog section

	Kirki::add_section('blog_section', array(
		'title' => esc_attr__('Blog', 'myfolio') ,
		'panel' => 'myfolio_panel',
		'priority' => 160,
	));

	// blog page title

	Kirki::add_field('theme_config_id', array(
		'type' => 'text',
		'settings' => 'blog_title_setting',
		'label' => __('Blog Page Title', 'myfolio') ,
		'section' => 'blog_section',
		'priority' => 10,
		'partial_refresh' => array(
			'blog_title_setting' => array(
				'selector' => '.title-header h1',
				'render_callback' =>
				function ()
				{
					echo Kirki::get_option('blog_title_setting');
				}

				,
			) ,
		) ,
	));

	// 404 section

	Kirki::add_section('error_section', array(
		'title' => esc_attr__('404', 'myfolio') ,
		'panel' => 'myfolio_panel',
		'priority' => 160,
	));

	// 404 Title

	Kirki::add_field('theme_config_id', array(
		'type' => 'text',
		'settings' => 'error_title_setting',
		'label' => __('404 Title', 'myfolio') ,
		'section' => 'error_section',
		'priority' => 10,
		'partial_refresh' => array(
			'error_title_setting' => array(
				'selector' => '.error-title',
				'render_callback' =>
				function ()
				{
					echo Kirki::get_option('error_title_setting');
				}

				,
			) ,
		) ,
	));

	// 404 Text

	Kirki::add_field('theme_config_id', array(
		'type' => 'textarea',
		'settings' => 'error_text_setting',
		'label' => __('Error Text', 'myfolio') ,
		'section' => 'error_section',
		'priority' => 10,
		'partial_refresh' => array(
			'error_text_setting' => array(
				'selector' => '.error-text',
				'render_callback' =>
				function ()
				{
					echo Kirki::get_option('error_text_setting');
				}

				,
			) ,
		) ,
	));

	// footer section

	Kirki::add_section('footer_section', array(
		'title' => esc_attr__('Footer', 'myfolio') ,
		'panel' => 'myfolio_panel',
		'priority' => 160,
	));

	// footer text

	Kirki::add_field('theme_config_id', array(
		'type' => 'editor',
		'settings' => 'footer_text_setting',
		'label' => __('Footer Copyright text', 'myfolio') ,
		'section' => 'footer_section',
		'priority' => 10,
		'partial_refresh' => array(
			'footer_text_setting' => array(
				'selector' => '.copyright-text',
				'render_callback' =>
				function ()
				{
					echo Kirki::get_option('footer_text_setting');
				}

				,
			) ,
		) ,
	));

	// footer social icon

	Kirki::add_field('theme_config_id', array(
		'type' => 'repeater',
		'label' => esc_attr__('Social Icons', 'myfolio') ,
		'section' => 'footer_section',
		'priority' => 10,
		'row_label' => array(
			'type' => 'text',
			'value' => esc_attr__('Your social icon', 'myfolio') ,
		) ,
		'button_label' => esc_attr__('"Add new" social icon', 'myfolio') ,
		'settings' => 'footer_social_icons',
		'default' => array(
			array(
				'link_text' => 'fa-facebook',
				'link_url' => 'https://facebook.com',
			) ,
			array(
				'link_text' => 'fa-twitter',
				'link_url' => 'https://twitter.com',
			) ,
			array(
				'link_text' => 'fa-github',
				'link_url' => 'https://github.com',
			) ,
			array(
				'link_text' => 'fa-behance',
				'link_url' => 'https://behance.com',
			) ,
			array(
				'link_text' => 'fa-dribbble',
				'link_url' => 'https://dribbble.com',
			)
		) ,
		'fields' => array(
			'link_text' => array(
				'type' => 'text',
				'label' => esc_attr__('FontAwesome Icon', 'myfolio') ,
				'default' => 'fa-facebook',
			) ,
			'link_url' => array(
				'type' => 'text',
				'label' => esc_attr__('Social URL', 'myfolio') ,
				'default' => '#',
			) ,
		) ,
		'partial_refresh' => array(
			'footer_social_icons' => array(
				'selector' => '.footer-social',
				'render_callback' =>
				function ()
				{
					echo Kirki::get_option('footer_social_icons');
				}

				,
			) ,
		) ,
	));
}