<?php 
namespace Elementor;
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Button
class myfolio_Widget_Button extends Widget_Base {
 
   public function get_name() {
      return 'button';
   }
 
   public function get_title() {
      return esc_html__( 'Button', 'myfolio' );
   }
 
   public function get_icon() { 
        return 'eicon-button';
   }
 
   public function get_categories() {
      return [ 'myfolio-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'button_section',
         [
            'label' => esc_html__( 'Button', 'myfolio' ),
            'type' => Controls_Manager::SECTION,
         ]
      );

      $this->add_control(
         'btn_color',
         [
            'label' => __( 'Color', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::COLOR
         ]
      );

      $this->add_control(
         'button_text', [
            'label' => __( 'Button Text', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
         ]
      );

      $this->add_control(
         'button_url', [
            'label' => __( 'Button URL', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
         ]
      );

      $this->add_control(
         'align',
         [
            'label' => __( 'Align', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'default' => 'solid',
            'options' => [
               'center'  => __( 'Center', 'myfolio' ),
               'left' => __( 'Left', 'myfolio' ),
               'right' => __( 'Right', 'myfolio' )
            ],
         ]
      );

      $this->end_controls_section();

   }

   protected function render( $instance = [] ) {
 
      // get our input from the widget settings.
       
      $settings = $this->get_settings_for_display();
      
      //Inline Editing
      $this->add_inline_editing_attributes( 'btn_color', 'basic' );
      $this->add_inline_editing_attributes( 'button_text', 'basic' );
      $this->add_inline_editing_attributes( 'button_url', 'basic' );
      $this->add_inline_editing_attributes( 'align', 'basic' );
      ?>
      <div style="text-align: <?php echo esc_attr($settings['align']) ?>">
         <a style="background: <?php echo esc_attr($settings['btn_color']) ?>; <?php if ( !$settings['btn_color']=='' ) {
           echo "color: #fff";} ?>" class="myfolio-btn" href="<?php echo esc_url( $settings['button_url'] ); ?>">
         <?php if ($settings['button_icon']): ?>
         <?php endif ?><?php echo esc_html( $settings['button_text'] ); ?></a>
      </div>
      <?php
   }
 
}

Plugin::instance()->widgets_manager->register_widget_type( new myfolio_Widget_Button );