<?php 
namespace Elementor;
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// portfolio
class myfolio_Widget_Portfolio extends Widget_Base {
 
   public function get_name() {
      return 'portfolio';
   }
 
   public function get_title() {
      return esc_html__( 'portfolio', 'myfolio' );
   }
 
   public function get_icon() { 
        return 'eicon-gallery-masonry';
   }
 
   public function get_categories() {
      return [ 'myfolio-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'portfolio_section',
         [
            'label' => esc_html__( 'portfolio', 'myfolio' ),
            'type' => Controls_Manager::SECTION,
         ]
      );

      $this->add_control(
         'ppp',
         [
            'label' => __( 'number of portfolio', 'myfolio' ),
            'type' => Controls_Manager::SLIDER,
            'range' => [
               'no' => [
                  'min' => 0,
                  'max' => 100,
                  'step' => 1,
               ],
            ],
            'default' => [
               'size' => 9,
            ]
         ]
      );

      $this->add_control(
         'order',
         [
            'label' => __( 'order', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'default' => 'ASC',
            'options' => [
               'ASC'  => __( 'ascending', 'myfolio' ),
               'DESC' => __( 'descending', 'myfolio' )
            ],
         ]
      );

      $this->end_controls_section();

   }

   protected function render( $instance = [] ) {
 
      // get our input from the widget settings.
       
      $settings = $this->get_settings_for_display();
      
      //Inline Editing
      $this->add_inline_editing_attributes( 'ppp', 'basic' );
      ?>

      <div class="container-fluid">
         <div class="row">
            <div class="col-sm-12">
               <div class="filter-project-carousel">
               <?php

               $portfolio = new \WP_Query( array( 
                  'post_type' => 'portfolio',
                  'posts_per_page' => $settings['ppp']['size'],
                  'order' => $settings['order'],
               ));

               /* Start the Loop */
               while ( $portfolio->have_posts() ) : $portfolio->the_post(); 

                 $portfolio_terms = get_the_terms( get_the_ID() , 'portfolio_category' );

               ?>
                  <!-- Item -->
                  <div class="filter-project-item <?php foreach ($portfolio_terms as $portfolio_term) { echo esc_attr( $portfolio_term->slug ); } ?>">
                     <?php the_post_thumbnail( 'myfolio-600x770' ) ?>
                     <div class="project_content">
                        <?php the_title( '<h2>', '</h2>' ) ?>
                        <span><?php foreach ($portfolio_terms as $portfolio_term) { echo esc_attr( $portfolio_term->name ); } ?></span>
                        <a class="project-popup" href="<?php echo get_the_post_thumbnail_url(); ?>" data-effect="mfp-zoom-in"><img src="<?php echo get_template_directory_uri() ?>/images/plus-symbol.png" alt=""></a>
                     </div>
                  </div>

               <?php 
               endwhile; 
               wp_reset_postdata();
            ?>
               </div>
            </div>
         </div>
      </div>

      <?php
   }
 
}

Plugin::instance()->widgets_manager->register_widget_type( new myfolio_Widget_Portfolio );