<?php 
namespace Elementor;
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// progress
class myfolio_Widget_ProgressBar extends Widget_Base {
 
   public function get_name() {
      return 'progress_bar';
   }
 
   public function get_title() {
      return esc_html__( 'Progress Bar', 'myfolio' );
   }
 
   public function get_icon() { 
        return 'eicon-skill-bar';
   }
 
   public function get_categories() {
      return [ 'myfolio-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'service_section',
         [
            'label' => esc_html__( 'progress', 'myfolio' ),
            'type' => Controls_Manager::SECTION,
         ]
      );
      
      $this->add_control(
         'title',
         [
            'label' => __( 'Title', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => 'WordPress',
         ]
      );

      $this->add_control(
         'percentage',
         [
            'label' => __( 'Percentage', 'myfolio' ),
            'type' => Controls_Manager::SLIDER,
            'range' => [
               'no' => [
                  'min' => 0,
                  'max' => 100,
                  'step' => 1,
               ],
            ],
            'default' => [
               'size' => 70,
            ]
         ]
      );
      
      $this->end_controls_section();

   }

   protected function render( $instance = [] ) {
 
      // get our input from the widget settings.
       
      $settings = $this->get_settings_for_display();
      
      //Inline Editing
      $this->add_inline_editing_attributes( 'title', 'basic' );
      $this->add_inline_editing_attributes( 'percentage', 'basic' );
      ?>

      <p class="progress-title"><?php echo esc_html($settings['title']); ?></p>

      <div class="progressbar-item" data-perc="<?php echo esc_attr($settings['percentage']['size']); ?>">
         <div class="bar"><span></span></div>
         <div class="label"><span></span></div>
      </div>

      <?php
   }
 
}

Plugin::instance()->widgets_manager->register_widget_type( new myfolio_Widget_ProgressBar );