<?php 
namespace Elementor;
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Testimonials
class myfolio_Widget_Testimonials extends Widget_Base {
 
   public function get_name() {
      return 'testimonials';
   }
 
   public function get_title() {
      return esc_html__( 'Testimonials', 'myfolio' );
   }
 
   public function get_icon() { 
        return 'eicon-testimonial';
   }
 
   public function get_categories() {
      return [ 'myfolio-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'testimonials_section',
         [
            'label' => esc_html__( 'Testimonials', 'myfolio' ),
            'type' => Controls_Manager::SECTION,
         ]
      );

      $this->add_control(
         'title',
         [
            'label' => __( 'Title', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT
         ]
      );

      $repeater = new \Elementor\Repeater();

      $repeater->add_control(
         'image',
         [
            'label' => __( 'choose photo', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
               'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
         ]
      );
      
      $repeater->add_control(
         'name',
         [
            'label' => __( 'name', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT
         ]
      );

      $repeater->add_control(
         'designation',
         [
            'label' => __( 'designation', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT
         ]
      );


      $repeater->add_control(
         'testimonial',
         [
            'label' => __( 'Testimonial', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXTAREA
         ]
      );

      $this->add_control(
         'testimonial_list',
         [
            'label' => __( 'Testimonial List', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => 'testimonial_list',

         ]
      );
      
      $this->end_controls_section();

   }

   protected function render( $instance = [] ) {
 
      // get our input from the widget settings.
       
      $settings = $this->get_settings_for_display();
      
      //Inline Editing
      $this->add_inline_editing_attributes( 'title', 'basic' );
      $this->add_inline_editing_attributes( 'testimonial_list', 'basic' );
      ?>
   
      <div class="container">
         <div class="row">
            <div class="col-lg-6 ">
               <h1><?php echo esc_html($settings['title']); ?></h1>
               <div class="testimonials">

               <?php foreach (  $settings['testimonial_list'] as $testimonial ): ?>
                  <div class="testimonial">
                     <div class="testimonial-content">
                        <p><i class="fa fa-3x fa-quote-left"></i><?php echo esc_html($testimonial['testimonial']); ?></p>
                           <img  class="float-left" src="<?php echo esc_url($testimonial['image']['url']); ?>" alt="Logo">
                           <h6><?php echo esc_html($testimonial['name']); ?></h6>
                           <span><?php echo esc_html($testimonial['designation']); ?></span>
                     </div>        
                  </div>
                  
               <?php endforeach ?>
               </div>

            </div>

            <div class="col-lg-6 hidden-md-down">
               <div class="testimonial-integrator">
                  <?php foreach (  $settings['testimonial_list'] as $key => $testimonial ): ?>
                  <a href="#" class="testi-nav rotateIn animated elementor-element animated-slow" data-settings="{"_animation":"rotateIn","_animation_delay":<?php echo $key ?>00}" data-slide-index="<?php echo $key ?>">
                     <img src="<?php echo esc_url($testimonial['image']['url']); ?>" alt="Logo">                 
                  </a>
               <?php endforeach ?>
               </div>
            </div>
         </div>
      </div>
      <?php
   }
}

Plugin::instance()->widgets_manager->register_widget_type( new myfolio_Widget_Testimonials );