<?php 
namespace Elementor;
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Title
class myfolio_Widget_Title extends Widget_Base {
 
   public function get_name() {
      return 'title';
   }
 
   public function get_title() {
      return esc_html__( 'Title', 'myfolio' );
   }
 
   public function get_icon() { 
        return 'eicon-site-title';
   }
 
   public function get_categories() {
      return [ 'myfolio-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'title_section',
         [
            'label' => esc_html__( 'Title', 'myfolio' ),
            'type' => Controls_Manager::SECTION,
         ]
      );

      $this->add_control(
         'align',
         [
            'label' => __( 'Align', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'default' => 'left',
            'options' => [
               'center'  => __( 'Center', 'myfolio' ),
               'left' => __( 'Left', 'myfolio' ),
               'right' => __( 'Right', 'myfolio' )
            ],
         ]
      );
      
      $this->add_control(
         'title',
         [
            'label' => __( 'Title', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT
         ]
      );

      $this->add_control(
         'colored-title',
         [
            'label' => __( 'Colored Title', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
         ]
      );

      $this->add_control(
         'white-color',
         [
            'label' => __( 'White Text When BG Colored', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'label_on' => __( 'On', 'myfolio' ),
            'label_off' => __( 'Off', 'myfolio' ),
            'return_value' => 'yes',
            'default' => 'no',
   
         ]
      );

      $this->add_control(
         'text',
         [
            'label' => __( 'Text', 'myfolio' ),
            'type' => \Elementor\Controls_Manager::TEXTAREA
         ]
      );
      
      $this->end_controls_section();

   }

   protected function render( $instance = [] ) {
 
      // get our input from the widget settings.
       
      $settings = $this->get_settings_for_display();
      
      //Inline Editing
      $this->add_inline_editing_attributes( 'align', 'basic' );
      $this->add_inline_editing_attributes( 'title', 'basic' );
      $this->add_inline_editing_attributes( 'colored-title', 'basic' );
      $this->add_inline_editing_attributes( 'white-color', 'basic' );
      $this->add_inline_editing_attributes( 'text', 'basic' );
      ?>
      <div class="section-title <?php if('yes' === $settings['white-color']){echo 'title-white-color';} ?>" style="text-align: <?php echo esc_attr($settings['align']); ?>">
         <h2 <?php echo $this->get_render_attribute_string( 'title' ); ?>><?php echo esc_html($settings['title']); ?><span <?php if ( $settings['align'] == 'center' ) { echo 'class="span-inline"';} ?>><?php echo esc_html($settings['colored-title']); ?></span></h2>
         <p <?php if ( $settings['align'] == 'center' ) { echo 'class="title-desc"';} ?><?php echo $this->get_render_attribute_string( 'text' ); ?>><?php echo esc_html($settings['text']); ?></p>
      </div>
      <?php
   }
 
   protected function _content_template() {?>
      <#
      view.addInlineEditingAttributes( 'align', 'basic' );
      view.addInlineEditingAttributes( 'icon', 'basic' );
      view.addInlineEditingAttributes( 'title', 'basic' );
      view.addInlineEditingAttributes( 'text', 'basic' );
      #>
      <div class="section-title" style="text-align: {{{ settings.align}}}">
         <# if ( settings.icon ) { #>
         <i class="{{ settings.icon }} fa-2x" aria-hidden="true"></i>
         <# } #>
         <h2 {{{ view.getRenderAttributeString( 'title' ) }}}>{{{ settings.title}}}</h2>
         <p {{{ view.getRenderAttributeString( 'text' ) }}}>{{{ settings.text}}}</p>
      </div>
      <?php
   }
 
}

Plugin::instance()->widgets_manager->register_widget_type( new myfolio_Widget_Title );